pub enum TorahReadingType {
YomTov,
Chol,
Shabbos,
SpecialParsha,
}Expand description
What Torah Readings are we looking for
Variants
YomTov
Yom Tov - Pesach, Shavuos, Sukkos, Shmini Atzeres/Simchas Torah, Rosh Hashana, Yom Kippur and Chol HaMoed.
Chol
Weekday Torah reading - Rosh Chodesh, Chanuka and Purim
Shabbos
Weekly Parsha Torah reading
SpecialParsha
One of the four special Torah portions read every winter (Shekalim, Zachor, Parah and HaChodesh).